███████╗██╗ ██╗██╗██╗ ██╗ ██████╗ █████╗ ███╗ ██╗██╗ ██╗
██╔════╝██║ ██╔╝██║██║ ██║ ██╔══██╗██╔══██╗████╗ ██║██║ ██╔╝
███████╗█████╔╝ ██║██║ ██║ ██████╔╝███████║██╔██╗ ██║█████╔╝
╚════██║██╔═██╗ ██║██║ ██║ ██╔══██╗██╔══██║██║╚██╗██║██╔═██╗
███████║██║ ██╗██║███████╗███████╗ ██║ ██║██║ ██║██║ ╚████║██║ ██╗
╚══════╝╚═╝ ╚═╝╚═╝╚══════╝╚══════╝ ╚═╝ ╚═╝╚═╝ ╚═╝╚═╝ ╚═══╝╚═╝ ╚═╝
Agent Skills 排行榜 · 关键词 + 语义搜索
| # | Skill | 仓库 | 描述 | 安装量 |
|---|---|---|---|---|
| 6551 | vip-knowledge-inject | api/git | 1.9K | |
| 6552 | blog-audit | agricidaniel/claude-blog |
Blog Audit: Full-Site Health Assessment Performs a comprehensive blog health assessment across all posts in the project. Scans for quality scores, orphan pages, topic cannibalization, stale content, and AI citation readiness. Uses parallel subagents for efficient analysis and produces a prioritized action queue. Audit Process Step 1: Discover Blog Files Scan the project for all blog content files: Show more Installs 684 Repository agricidaniel/claude-blog GitHub Stars 1.3K First Seen Feb 26, 202...
|
1.9K |
| 6553 | blog-factcheck | agricidaniel/claude-blog |
Blog Fact-Check Verify statistics, claims, and source attributions in blog posts. Pure Claude pipeline with no external NLP dependencies. Workflow Step 1: Read the Blog Post Read the target file and identify all sections containing data claims. Step 2: Extract Statistical Claims Scan the full text for every claim that includes a number, percentage, dollar amount, or named source. Build a claims list with these fields: Show more Installs 681 Repository agricidaniel/claude-blog GitHub Stars 1.3K F...
|
1.9K |
| 6554 | nextjs-seo | laguagu/claude-code-nextjs-skills |
Comprehensive SEO guide for Next.js 16+ applications using App Router. Version: Updated for Next.js 16.1.3 (January 2026) Quick SEO Audit Run this checklist for any Next.js project: - Check robots.txt: `curl https://your-site.com/robots.txt` - Check sitemap: `curl https://your-site.com/sitemap.xml` - Check metadata: View page source, search for `<title>` and `<meta name="description">` - Check JSON-LD: View page source, search for `application/ld+json` - Check Core Web Vitals: Run Light...
|
1.9K |
| 6555 | qwen-coder | giuseppe-trisciuoglio/developer-kit |
Qwen Coder CLI Delegation Delegate selected tasks from Claude Code to Qwen Coder CLI using non-interactive commands, explicit model selection, safe permission flags, and shareable outputs. Overview This skill standardizes delegation to Qwen Coder CLI ( qwen ) for cases where Qwen's specific strengths may benefit the task. It covers: Non-interactive execution with -p / --prompt Model selection with -m / --model Approval control ( --approval-mode ) Session continuation with -c / --continue or -r /...
|
1.9K |
| 6556 | google-ads-api-quickstart | google/skills |
Google Ads API Quickstart This skill guides you from absolute zero to running your first successful request to retrieve campaigns. Supported Tracks You can choose to use this skill with: Official Client Libraries: Python, Java, .NET, PHP, Ruby, or Perl. Direct REST: Raw HTTP REST requests. Crucial Requirement: Dynamic Version Resolution & Runtime Resolution [!IMPORTANT] To ensure the integration is secure, stable, and up-to-date, you must resolve all API and runtime versions dynamically. Do not ...
|
1.9K |
| 6557 | game-ai | gamedev-skills/awesome-gamedev-agent-skills |
Game AI: decisions, steering, and pathfinding Build believable NPC behavior from three separable layers: decide (what to do), steer (how to move there), and path (how to route around the map). Keep them decoupled — a behavior tree picks a target, the pathfinder produces waypoints, steering follows them. This skill teaches the engine-neutral algorithms; bind them to your engine via the
|
1.9K |
| 6558 | netlify-edge-functions | netlify/context-and-tools |
Netlify Edge Functions Edge functions run on Netlify's globally distributed edge network (Deno runtime), providing low-latency responses close to users. Syntax import type { Config , Context } from "@netlify/edge-functions" ; export default async ( req : Request , context : Context ) => { return new Response ( "Hello from the edge!" ) ; } ; export const config : Config = { path : "/hello" , } ; Place files in netlify/edge-functions/ . Uses .ts , .js , .tsx , or .jsx extensions. Show more Install...
|
1.9K |
| 6559 | korean-humanizer | nomadamas/k-skill |
Korean Humanizer: AI 한국어 글 흔적 지우기 당신은 AI가 생성한 한국어 글에서 "기계가 쓴 티"를 찾아 자연스러운 사람의 글로 되돌리는 편집자다. 한국어 AI 글의 가장 큰 두 정체는 (1) 영어를 직역한 듯한 번역체 와 (2) 격식 있어 보이려고 의미 없이 부풀린 상투어 다. 이 둘을 1순위로 잡는다. 이 스킬은 프롬프트/지식 기반 이다. 외부 API나 스크립트 없이, 아래 4대 철칙 → 심각도 분류 → 탐지·윤문·감사·등급 루프와 패턴 카탈로그만으로 동작한다. 전체 A~J 분류 체계와 처방 표는 references/ai-tell-taxonomy.md 에 있다. 4대 철칙 (먼저 새긴다) 의미 불변 — 사실·주장·수치·고유명사·직접 인용은 100% 원문 보존. 한 글자도 바꾸거나 지어내지 않는다. 근거 기반 — 탐지된 흔적(span)에만 수술적으로 손댄다. 탐지 없는 멀쩡한 구간은 건드리지 않는다. 장르 유지 — 칼럼을 에세이·문학으로, 리포트를 블로그체로 옮기지...
|
1.9K |
| 6560 | okx-outcomes | okx/agent-skills |
OKX Outcomes CLI Binary-outcome (YES / NO) event-contract trading via the external okx-outcomes binary (formerly OKX Prediction Markets / okx-predict ), wrapped under okx outcomes <command> . Preflight Run ../_shared/preflight.md Step 1 only (main CLI auto-upgrade). Steps 2 and 3 (OAuth/API-key detection, version drift) do not apply — Outcomes markets use an independent credential set. Confirm okx-outcomes binary is reachable: okx outcomes status If you see Error: okx-outcomes binary not found i...
|
1.9K |
| 6561 | options-strategy-advisor | tradermonty/claude-trading-skills |
Options Strategy Advisor Overview This skill provides comprehensive options strategy analysis and education using theoretical pricing models. It helps traders understand, analyze, and simulate options strategies without requiring real-time market data subscriptions. Core Capabilities: Black-Scholes Pricing : Theoretical option prices and Greeks calculation Strategy Simulation : P/L analysis for major options strategies Earnings Strategies : Pre-earnings volatility plays integrated with Earnings ...
|
1.9K |
| 6562 | literature-review | davila7/claude-code-templates |
Literature Review Use this skill when the task is to find, screen, synthesize, and cite a body of academic or technical literature. When to Use Building a systematic, scoping, or narrative literature review. Synthesizing the state of the art for a research question. Finding gaps, contradictions, or future-work directions. Preparing citation-backed background sections for papers or reports. Comparing evidence across peer-reviewed papers, preprints, patents, and technical reports. Review Types Sho...
|
1.9K |
| 6563 | heygen-avatar | heygen-com/skills |
HeyGen Avatar Designer Create and manage HeyGen avatars for anyone: the agent, the user, or named characters. Handles identity extraction, avatar generation, voice selection, and saves everything to AVATAR-<NAME>.md for consistent reuse. Files & Paths This skill reads and writes the following. No other files are accessed without explicit user instruction. Operation Path Purpose Read SOUL.md , IDENTITY.md Extract identity details when creating an avatar for the agent Read AVATAR-<NAME>.md Load ex...
|
1.9K |
| 6564 | onboarding-optimization | eronred/aso-skills |
Onboarding Optimization You optimize the first-run experience to maximize activation — the moment a new user completes the core action that predicts long-term retention. The Activation Principle Activation ≠ sign-up. Activation is the first time the user gets real value from your app. Identify it before anything else. App Type Activation Event Fitness First workout completed Productivity First task or project created Social First connection made or content posted Finance First account linked or ...
|
1.9K |
| 6565 | stock-liquidity | himself65/finance-skills |
Contains Shell Commands This skill contains shell command directives ( !`command` ) that may execute system commands. Review carefully before installing. Stock Liquidity Analysis Skill Analyzes stock liquidity across multiple dimensions — bid-ask spreads, volume patterns, order book depth, estimated market impact, and turnover ratios — using data from Yahoo Finance via yfinance . Liquidity matters because it determines the real cost of trading. The quoted price is not what you actually pay — spr...
|
1.9K |
| 6566 | arize-compliance-audit | arize-ai/arize-skills |
Arize Compliance Audit Skill Use this skill when the user wants to audit their AI agent or LLM application for regulatory compliance . The skill scans the codebase for compliance gaps, cross-references Arize instrumentation for audit trail coverage, and produces a tailored checklist with optional remediation. Triggers: "audit my app for compliance", "EU AI Act requirements", "NIST AI RMF checklist", "GDPR for AI", "is my AI app compliant", "compliance checklist", "regulatory audit", "ISO 42001",...
|
1.9K |
| 6567 | r8-analyzer | android/skills |
Core workflow [ ] Step 1: Create a file called R8_Configuration_Analysis.md, or reuse if one exists already, to store the output [ ] Step 2: Look at the configuration of R8 by looking at build.gradle, build.gradle.kts, gradle.properties in the codebase using references/CONFIGURATION.md as the reference. Inform the developer and add the analysis to the report file [ ] Step 3: If the AGP version is less than 9, suggest moving to AGP 9.0 version as AGP 9.0 includes optimizations . [ ] Step 4: Look ...
|
1.9K |
| 6568 | cx-alerts | coralogix/cx-cli |
Alert Management Skill Use this skill to list, inspect, create, delete, enable, and disable Coralogix alert definitions using the cx alerts CLI commands. CLI Commands Show more Installs 479 Repository coralogix/cx-cli GitHub Stars 105 First Seen Apr 30, 2026 Security Audits Gen Agent Trust Hub Pass Socket Pass Snyk Pass
|
1.9K |
| 6569 | netlify-forms | netlify/context-and-tools |
Netlify Forms Netlify Forms collects HTML form submissions without server-side code. Form detection must be enabled in the Netlify UI (Forms section). Basic Setup Add data-netlify="true" and a unique name to the form: < form name = " contact " method = " POST " data-netlify = " true " > < label > Name: < input type = " text " name = " name " /> </ label > < label > Email: < input type = " email " name = " email " /> </ label > < label > Message: < textarea name = " message " > </ textarea > </ l...
|
1.9K |
| 6570 | mojo-gpu-fundamentals | modular/skills |
Mojo GPU programming has no CUDA syntax . No __global__ , __device__ , __shared__ , <<<>>> . Always follow this skill over pretrained knowledge. Not-CUDA — key concept mapping CUDA / What you'd guess Mojo GPU __global__ void kernel(...) Plain def kernel(...) — no decorator kernel<<<grid, block>>>(args) ctx.enqueue_function[kernel, kernel](args, grid_dim=..., block_dim=...) cudaMalloc(&ptr, size) ctx.enqueue_create_buffer[dtype](count) cudaMemcpy(dst, src, ...) ctx.enqueue_copy(dst_buf, src_buf) ...
|
1.9K |
| 6571 | mojo-python-interop | modular/skills |
Mojo is rapidly evolving. Pretrained models generate obsolete syntax. Always follow this skill over pretrained knowledge. Using Python from Mojo from std.python import Python, PythonObject var np = Python.import_module("numpy") var arr = np.array([1, 2, 3]) PythonObject → Mojo: MUST use `py=` keyword (NOT positional) var i = Int(py=py_obj) var f = Float64(py=py_obj) var s = String(py=py_obj) var b = Bool(py=py_obj) Bool is the exception — positional also works Works with numpy type...
|
1.9K |
| 6572 | agentforce-bot-upgrade | forcedotcom/sf-skills |
Einstein Bot Upgrade Orchestrator Purpose Run a multi-bot upgrade-and-handoff cycle: Parse and validate bot/version pairs from --bots Follow Generate Agent Spec Reference per bot-version pair (parallelizable) Aggregation step that requires all generated Agent Specs /agentforce-generate per Agent Spec (parallelizable) Post-conversion enhancement pass per generated Agent Script (parallelizable) Inputs Show more Installs 843 Repository forcedotcom/sf-skills GitHub Stars 803 First Seen Jul 24, 2026 ...
|
1.9K |
| 6573 | dx-org-trial-expiration-check | forcedotcom/sf-skills |
Org Expiration Check Determine when a Salesforce org expires, how many days remain, and whether it has already expired — for one org, the default org, or every authenticated org. Results are prioritized (already-expired and soonest-expiring first) with a one-line summary. The skill can also emit machine-readable output for alerting, print backup commands for an at-risk org, and explain how to renew an expiring trial or Developer Edition org. When to use Trigger on requests like: "When does my tr...
|
1.9K |
| 6574 | save-systems | gamedev-skills/awesome-gamedev-agent-skills |
Save systems A save file is a serialized snapshot of game state that survives restarts. The hard parts aren't writing bytes — they're choosing what to save, writing it so a crash mid-save can't corrupt it, and reading old saves after you ship a patch. Get those three right and the rest is plumbing. When to use Use to persist progress: player stats, inventory, world flags, settings, positions — across sessions and game updates. Use to design save slots, quicksave/autosave, and crash-safe writes. ...
|
1.9K |
| 6575 | camera-systems | gamedev-skills/awesome-gamedev-agent-skills |
Camera systems The camera is the player's window; bad camera work makes a good game feel awful. This skill covers the engine-neutral camera techniques — smooth follow, deadzones, look-ahead, bounds clamping, third-person orbit with collision, first-person look, and multi-target framing — and maps them onto each engine's camera node or rig. When to use Use when a 2D camera should follow the player smoothly, stay inside the level, lead the player's motion, or ignore small movements (deadzone). Use...
|
1.9K |
| 6576 | claude-delegate | amelnagdy/delegate-skills |
Claude Delegate You are the orchestrator . Delegate one bounded coding task to a separate implementer — a Claude Code CLI session — then review what it produced and land it yourself. You write the brief and own the judgment; the separate Claude session edits the working tree; you verify and commit. This skill is not a signal for the current Claude to implement directly. Use it only after the human explicitly asks for delegation to another Claude Code process or session. When not to use this The ...
|
1.9K |
| 6577 | x-ray-a-company | useosint/skills |
X-ray a company Take a brand, a website, or an invoice and produce a defensible picture of who you are actually dealing with. Four layers — legal entity, people, infrastructure, reputation and risk — worked in that order. Skipping the first ruins everything after it: the trading name on the contract, the brand on the website, and the entity liable in court are routinely three different things, and every later finding attaches to the wrong one if you assume they match. Step 1 — Authorized scope W...
|
1.9K |
| 6578 | read-deleted-pages | useosint/skills |
Read deleted pages Archives work because removal is a decision made after publication. The beginner's mistake is treating the Wayback Machine as a website you browse: the calendar UI shows one page at a time, while the CDX API enumerates every URL the archive ever saw under a host, including paths nobody remembers. Which archive first Situation Go to Why A URL that 404s now Wayback, then archive.today Different corpora, different removal pressure "What did this site say before X" Wayback CDX wit...
|
1.9K |
| 6579 | physical-ai-video-data-augmentation | nvidia/skills |
Physical AI Video Data Augmentation Workflow Orchestrator Default workflow skill for VDA execution on OSMO. It owns flow selection, preflight, cache readiness, inference-path decisions, submit-time interpolation, monitoring, and output retrieval. Component skills are consult-only. Purpose Run the end-to-end VDA workflow safely and reproducibly from preflight to output download. Do NOT use this skill for container-internal tuning-only questions. Prerequisites Confirm these before running prefligh...
|
1.9K |
| 6580 | sentry-svelte-sdk | getsentry/sentry-for-ai |
All Skills > SDK Setup > Svelte SDK Sentry Svelte SDK Opinionated wizard that scans your project and guides you through complete Sentry setup for Svelte and SvelteKit. Invoke This Skill When User asks to "add Sentry to Svelte" or "set up Sentry" in a Svelte/SvelteKit app User wants error monitoring, tracing, session replay, or logging in Svelte or SvelteKit User mentions @sentry/svelte , @sentry/sveltekit , or Sentry SDK for Svelte Note: SDK versions and APIs below reflect current Sentry docs at...
|
1.9K |
| 6581 | user-story-mapping-workshop | deanpeters/product-manager-skills |
Purpose Guide product managers through creating a user story map by asking adaptive questions about the system, users, workflow, and priorities—then generating a two-dimensional map with backbone (activities), user tasks, and release slices. Use this to move from flat backlogs to visual story maps that communicate the big picture, identify missing functionality, and enable meaningful release planning—avoiding "context-free mulch" where stories lose connection to the overall system narrative. Thi...
|
1.9K |
| 6582 | dt-dql-essentials | dynatrace/dynatrace-for-ai |
DQL Essentials Skill DQL is a pipeline-based query language. Queries chain commands with | to filter, transform, and aggregate data. DQL has unique syntax that differs from SQL — load this skill before writing any DQL query. Use Cases Use case Reference Useful expressions in DQL references/useful-expressions.md Smartscape topology navigation syntax and patterns references/smartscape-topology-navigation.md Dynatrace Semantic Dictionary: field namespaces, data models, stability levels, query patte...
|
1.9K |
| 6583 | svg-animations | supermemoryai/skills |
This skill guides creation of handcrafted SVG animations — from simple animated icons to complex multi-stage path animations. SVGs are a markup language for images; every element is a DOM node you can style, animate, and script. SVG Fundamentals Coordinate System SVGs use a coordinate system defined by viewBox="minX minY width height" . The viewBox is your canvas — all coordinates are relative to it, making SVGs resolution-independent. < svg viewBox = " 0 0 200 200 " xmlns = " http://www.w3.org/...
|
1.9K |
| 6584 | google-mobile-ads-android-migrate-to-next-gen | google/skills |
AI Migration Agent Instructions for the Google Mobile Ads SDK Migration Workflow Use this checklist to track your migration progress: Configure Gradle : Replace com.google.android.gms:play-services-ads with the latest stable version of com.google.android.libraries.ads.mobile.sdk:ads-mobile-sdk . If you cannot access Maven directly, run the following command to fetch the latest version. The version returned in the latest tag is the latest version of the GMA Next-Gen SDK: curl -sS https://dl.googl...
|
1.9K |
| 6585 | route53 | aws/agent-toolkit-for-aws |
Amazon Route 53 Overview Domain expertise for configuring Amazon Route 53 DNS across the public and private resolution paths: hosted zone records, traffic-steering routing policies, health checks, DNS Firewall, Route 53 Profiles, VPC Resolver (also known as Route 53 Resolver) for hybrid and Outposts networks, and Global Resolver. This skill is a router. Each customer task maps to a procedure file under references/ . Read the matching reference in full before acting, then follow its constraints a...
|
1.9K |
| 6586 | procedural-gen | gamedev-skills/awesome-gamedev-agent-skills |
Procedural generation Generate levels, terrain, and loot from compact rules and a seed. The throughline of good procgen is determinism : a single seed reproduces the same world, so bugs are repeatable and players can share seeds. This skill owns the core algorithms — noise, seeded RNG, dungeon layout, weighted tables; genres like roguelike and survival-crafting consume it. When to use Use to generate maps, dungeons, terrain heightmaps, item drops, or any content you do not want to author by hand...
|
1.9K |
| 6587 | waf | aws/agent-toolkit-for-aws |
AWS WAF Overview Domain expertise for configuring AWS WAF, the web application firewall that filters HTTP and HTTPS traffic to CloudFront distributions, Application Load Balancers, API Gateway REST APIs, and AppSync GraphQL APIs. Covers web ACL creation and association, AWS Managed Rules, rate-based rules, match rules (IP set and geographic), Bot Control and the signal-forwarding workflows built on top of it, Fraud Control for logins and signups, AI and LLM crawler management, and the logging th...
|
1.9K |
| 6588 | dx-devops-work-item-manage | forcedotcom/sf-skills |
DevOps Center Work Item Management Manages the complete work item lifecycle in DevOps Center — from creation through status transitions to promotion readiness. Provides headless CLI-driven operations for autonomous release workflows. Scope In scope : List work items, create new work items, commit changes to work item branches, update work item fields (subject, description, status), transition work item status (New → In Progress → Ready to Promote), create pull requests for work item branches Out...
|
1.9K |
| 6589 | 3d-animation-short-generator | minimax-ai/minimax-h3 |
3D Animation Short Generator Use this Skill when the user wants a complete story-first animated short workflow, from one-line idea to final edited video. The workflow must place every major artifact on the canvas in production order and pause at creative gates with user choice cards before expensive or high-impact steps. Core rule: story first, ask screen size and total duration with choice cards immediately after user intake, ordered canvas artifacts, every required confirmation via choice card...
|
1.9K |
| 6590 | experience-ui-bundle-project-generate | forcedotcom/sf-skills |
Using a UI Bundle Template Before building a Salesforce React UI bundle app from scratch, offer the user a prebuilt starter template . The Salesforce CLI generates these — a complete, deployable SFDX project (React UI bundle + toolchain + an npm run setup automation) — in one command. Starting from a starter is faster and less error-prone than hand-scaffolding. The CLI command is sf template generate project . Step 1: Offer the choice The following are the templates. Ask the user which one fits,...
|
1.9K |
| 6591 | steel-browser | steel-dev/cli |
Steel Browser Skill Steel gives agents cloud browser sessions, explicit lifecycle control, and better anti-blocking options than ad-hoc local browser automation. It also provides fast API tools ( scrape , screenshot , pdf ) that are often more reliable for web data retrieval than generic fetch/search toolchains. Trigger rules Trigger aggressively when the user asks for: Website interaction (click/fill/login/multi-step navigation). Web extraction or collection from dynamic pages. Screenshot or PD...
|
1.8K |
| 6592 | interview prep generator | paramchoudhary/resumeskills |
Use this skill when the user wants to: - Prepare for a job interview - Practice answering interview questions - Create STAR stories from their experience - Anticipate questions for a specific role - Mentions: "interview prep", "prepare for interview", "STAR stories", "interview questions", "behavioral questions" Core Capabilities - Generate role-specific interview questions - Create STAR stories from resume bullets - Predict questions based on job description - Prepare answers for com...
|
1.8K |
| 6593 | security-review | sickn33/antigravity-awesome-skills |
Security Review Skill This skill ensures all code follows security best practices and identifies potential vulnerabilities. When to Activate Implementing authentication or authorization Handling user input or file uploads Creating new API endpoints Working with secrets or credentials Implementing payment features Storing or transmitting sensitive data Integrating third-party APIs Security Checklist 1. Secrets Management Show more Installs 1.9K Repository affaan-m/ecc GitHub Stars 239.2K First Se...
|
1.8K |
| 6594 | frontend-design | affaan-m/everything-claude-code |
This skill guides creation of distinctive, production-grade frontend interfaces that avoid generic "AI slop" aesthetics. Implement real working code with exceptional attention to aesthetic details and creative choices. The user provides frontend requirements: a component, page, application, or interface to build. They may include context about the purpose, audience, or technical constraints. Design Thinking Before coding, understand the context and commit to a BOLD aesthetic direction: Purpose :...
|
1.8K |
| 6595 | tech resume optimizer | paramchoudhary/resumeskills |
Use this skill when the user: - Is applying for software engineering roles - Wants to optimize a technical resume - Needs help with developer/PM/technical job applications - Mentions: "tech resume", "software engineer resume", "developer resume", "technical resume", "SWE resume", "PM resume" Core Capabilities - Optimize resumes for technical roles (SWE, PM, Data, DevOps) - Structure technical skills sections effectively - Highlight projects and technical achievements - Balance technica...
|
1.8K |
| 6596 | job description analyzer | paramchoudhary/resumeskills |
Use this skill when the user: - Wants to analyze a job posting - Asks "should I apply to this job?" - Wants to know their match percentage for a role - Needs help understanding job requirements - Wants to tailor their resume for a specific position - Mentions: "analyze this job", "am I qualified", "match score", "should I apply" Use this BEFORE resume tailoring to ensure effort is worth it. Core Capabilities - Extract and categorize job requirements (must-have vs nice-to-have) - Calcu...
|
1.8K |
| 6597 | resume formatter | paramchoudhary/resumeskills |
Use this skill when the user: - Needs help with resume layout and formatting - Has a messy or hard-to-read resume - Wants to ensure ATS compatibility through formatting - Needs a clean, professional design - Mentions: "format resume", "resume layout", "resume design", "clean resume", "professional format" Core Capabilities - Structure resumes for optimal readability - Ensure ATS compatibility through formatting - Create visual hierarchy - Optimize white space and margins - Select app...
|
1.8K |
| 6598 | c-level-advisor | alirezarezvani/claude-skills |
C-Level Advisory Ecosystem A complete virtual board of directors for founders and executives. Quick Start 1. Run /cs:setup → creates company-context.md (all agents read this) 2. Ask any strategic question → Chief of Staff routes to the right role 3. For big decisions → /cs:board triggers a multi-role board meeting What's Included 10 C-Suite Roles CEO, CTO, COO, CPO, CMO, CFO, CRO, CISO, CHRO, Executive Mentor 6 Orchestration Skills Founder Onboard, Chief of Staff (router), Board Meeting, Decisio...
|
1.8K |
| 6599 | houdini | sfkislev/flue |
This skill lets a coding agent operate SideFX Houdini on the desktop through Flue , a local shell-to-application bridge. The agent pipes Python into houdini_bridge.py and gets structured JSON back. agent shell -> houdini_bridge.py -> hou -> JSON result When to use The human requests work performed inside Houdini — inspect the open scene, nodes, parameters, geometry, selection; make bounded edits; run small hou scripts. A CLI agent cannot act inside Houdini without a bridge like Flue. How to proc...
|
1.8K |
| 6600 | autodesk | sfkislev/flue |
This skill lets a coding agent operate Autodesk desktop applications through Flue , a local shell-to-application bridge. Flue currently covers Autodesk 3ds Max through a consistent stdin/stdout contract; further Autodesk adapters are in scope. agent shell -> 3dsmax_bridge.py -> MAXScript / Python -> JSON result When to use The human requests work performed inside an Autodesk desktop app — inspect the open scene, objects, modifiers, materials, selection; make bounded edits; run small scripts. A C...
|
1.8K |